/* filenamecollector.js 

Purpose
This script can be used to collect file names for the protocollinker or the designmatrixgenerator.
If motion estimate confounds are to be used, please set the variable 'add3DMC' on line 13 to 'true' (without the quotes).

Installation
If the script is placed in /Documents/BVQXExtensions/Scripts/ it can be run from the BrainVoyager Scripts menu without opening the editor.

Usage
When activated via the Scripts menu or after pressing 'Run' in the Script Editor, the script will present files dialogs to select protocol files (*.prt), 
volume time course files (*.vtc) and ask for a motion estimates file (*_3DMC.sdm) if 'add3DMC = true'.
It will continue presenting file dialogs until 'Cancel' is selected for a protocol file. 
The script will then write a text file for all the filenames selected thus-far. The text file with the filenames will be saved in the directory of the first selected file.

The text file has the following structure:

<number of projects>
<prt project 1>
<vtc project 1>
(<*_3DMC.sdm project 1>)
...
<prt project n>
<vtc project n>
(<*_3DMC.sdm project n>)

Hester Breman, Brain Innovation, Ada Lovelace Day 2014.
*/

var projectfiles = new Array();
var nprojects;
var counter = 0;
var vtc, prt, sdm;

var add3DMC = false; // >> set this to true if motion estimates are to be added to the design matrix
var addResp = false;
var addPulse = false;

var prt, vtc, moco;
var doLoop = true;

// ~~~~ collect the names ~~~

BrainVoyagerQX.PrintToLog("filenamecollector > Start collecting filenames...");
while (doLoop) {

	prt = BrainVoyagerQX.BrowseFile("Please select the PRT for project " + (counter+1).toString(), "*.prt");

	if (prt.length == 0) {
		doLoop = false; // finished selecting files
	} else {
		BrainVoyagerQX.PrintToLog(prt);	
		vtc = BrainVoyagerQX.BrowseFile("Please select the VTC for project " + (counter+1).toString(), "*.vtc");
		BrainVoyagerQX.PrintToLog(vtc);
		if (add3DMC) {
			moco = BrainVoyagerQX.BrowseFile("Please select the motion estimates file for project " + (counter+1).toString(), "*_3DMC.sdm");
			BrainVoyagerQX.PrintToLog(moco);	
		}	
		projectfiles.push([prt, vtc, moco]);
		counter++;
	}
}
nprojects = counter;
BrainVoyagerQX.PrintToLog("filenamecollector > Number of projects: " + nprojects.toString());

// ~~~~ write the text file ~~~

if (nprojects > 0) {

	var firstfile = projectfiles[0][0];  
	var last = firstfile.lastIndexOf("/"); // search for last path separator
	var path = firstfile.substring(0, (last+1)); // now return path without filename
	var namesfile = new QFile(path + "prt_vtc_list.txt");
	BrainVoyagerQX.PrintToLog("filenamecollector > Write text file " + path + "prt_vtc_list.txt...");
	namesfile.open(new QIODevice.OpenMode(QIODevice.WriteOnly | QIODevice.Text));
	var textoutput = new QTextStream(namesfile);
	textoutput.writeString(nprojects.toString() + "\n");
	var counter = 0;
	for (counter=0; counter<nprojects; counter++) {
		textoutput.writeString(projectfiles[counter][0] +"\n");
		textoutput.writeString(projectfiles[counter][1] +"\n");
		if (add3DMC) {
			textoutput.writeString(projectfiles[counter][2] +"\n");
		}	
	}
	namesfile.close();
} else {
	BrainVoyagerQX.PrintToLog("filenamecollector > To few files to write text file.");
}

BrainVoyagerQX.PrintToLog("filenamecollector > Finished." +"\n");